#!/usr/bin/env python

##############################################################################
##
## Copyright (C) 2022 Narda Safety Test Solutions GmbH.
## Contact: www.narda-sts.com
##
## Redistribution and use in source and binary forms,
## with or without modification, are permitted provided that the following
## conditions are met:
##
## 1.) Redistributions of source code must retain the above copyright notice,
## this list of conditions and the following disclaimer.
##
## 2.) Redistributions in binary form must reproduce the above copyright
## notice, this list of conditions and the following disclaimer in the
## documentation and/or other materials provided with the distribution.
##
## 3.) Neither the name of the copyright holder nor the names of its
## contributors may be used to endorse or promote products derived from this
## software without specific prior written permission.
##
## 4.) EXPORT CONTROL
## The Software, including technical data /cryptographic software,
## may be subject to, German, European Union and U.S. export controls and
## may be subject to import or export controls in other countries.
## The Licensee agrees to strictly comply with all applicable import and
## export regulations. He specifically agrees, that he must not disclose or
## otherwise export or re-export the Licensed Software or any part thereof
## delivered under this end user license agreement (EULA) to any country
## (including a national or resident of such country) without a valid export
## or import license. Please be aware that the Software may contain
## US-Content, therefor the Licensee represent and warrant that he is not a
## citizen of, or otherwise located within, an embargoed nation (including
## without limitation Iran, Syria, Sudan, Cuba, North Korea) and that he is
## not otherwise prohibited under the Export Laws from receiving the Software.
## All rights to Use the Software are granted on condition that such rights
## are forfeited if the Licensee fails to comply with
## the terms of this Agreement.
##
## 5.) SEVERABILITY
## Should any provision of this Agreement be or become invalid, ineffective
## or unenforceable, the remaining provisions of this Agreement shall be
## valid. The parties agree to replace the invalid, ineffective or
## unenforceable provision by a valid, effective and enforceable provision
## which best meets the commercial intention of the parties.
## The same shall apply in case of omissions.
##
## 6.) APPLICABLE LAW AND PLACE OF JURISTICATION
## This Agreement shall be constituted under the law of Germany.
## The United Nations Convention on the International Sale of Goods
## shall not apply to this Agreement. The Place of Jurisdiction for any
## dispute between the Parties shall be Tübingen (Germany).
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
## TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
## PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL Narda Safety Test Solutions GmbH
## BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
## CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
## SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
## INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
## CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
## ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.
##
##############################################################################

import threading
from typing import List, Callable, Optional
import wx
import wx.grid
import numpy as np
import h5py
import time
import datetime as dt
import winsound
from nardascripting.base.usrscriptbase import *
from nardascripting.base.signalsharkdev import *
import nardascripting.base.toolbox as tb


@dataclass
class SettingsData(object):
    """Data class for DF autopilot settings"""
    min_distance_hysteresis: int = field(default=20, metadata={"XmlName": "MinDistanceHysteresis"})
    max_distance_hysteresis: int = field(default=5000, metadata={"XmlName": "MaxDistanceHysteresis"})
    pos_hysteresis_perc: int = field(default=20, metadata={"XmlName": "PosChangePercentage"})
    update_rate: int = field(default=15, metadata={"XmlName": "UpdateRate"})

    nav_dev_name: str = field(default="Navigator", metadata={"XmlName": "NavDevName"})
    nav_dev_port: int = field(default=4242, metadata={"XmlName": "NavDevPort"})
    nav_dev_auto_ip: bool = field(default=True, metadata={"XmlName": "NavDevAutoIP"})
    nav_dev_nic: str = field(default="", metadata={"XmlName": "NavDevNIC"})
    nav_dev_man_ip: str = field(default="127.0.0.1", metadata={"XmlName": "NavDevManualIP"})
    nav_auto_stop: bool = field(default=True, metadata={"XmlName": "NavAutoStop"})

    win_last_pos_x: int = field(default=200, metadata={"XmlName": "WinLastPosX"})
    win_last_pos_y: int = field(default=200, metadata={"XmlName": "WinLastPosY"})




